import { Mark, markInputRule, markPasteRule } from '@tiptap/core';

const inputRegex = /(?:^|\s)((?:==)((?:[^~]+))(?:==))$/gm;
const pasteRegex = /(?:^|\s)((?:==)((?:[^~]+))(?:==))/gm;
const Highlight = Mark.create({
    name: 'highlight',
    defaultOptions: {
        HTMLAttributes: {},
    },
    addAttributes() {
        return {
            color: {
                default: null,
                parseHTML: element => {
                    return {
                        color: element.getAttribute('data-color') || element.style.backgroundColor,
                    };
                },
                renderHTML: attributes => {
                    if (!attributes.color) {
                        return {};
                    }
                    return {
                        'data-color': attributes.color,
                        style: `background-color: ${attributes.color}`,
                    };
                },
            },
        };
    },
    parseHTML() {
        return [
            {
                tag: 'mark',
            },
        ];
    },
    renderHTML({ HTMLAttributes }) {
        return ['mark', HTMLAttributes, 0];
    },
    addCommands() {
        return {
            /**
             * Toggle a highlight mark
             */
            highlight: (attributes) => ({ commands }) => {
                return commands.toggleMark('highlight', attributes);
            },
        };
    },
    addKeyboardShortcuts() {
        return {
            'Mod-e': () => this.editor.commands.highlight(),
        };
    },
    addInputRules() {
        return [
            markInputRule(inputRegex, this.type),
        ];
    },
    addPasteRules() {
        return [
            markPasteRule(inputRegex, this.type),
        ];
    },
});

export default Highlight;
export { inputRegex, pasteRegex };
//# sourceMappingURL=tiptap-extension-highlight.esm.js.map
